@@ -86,13 +86,36 @@ class MutableDate(object):
             self._date -= timedelta(microseconds=amount)
         return self
 
-    def epoch(self, rounding=True):
+    def replace(self, **kwds):
+        """A Pythonic way to replace various date attributes."""
+        for key, value in kwds.iteritems():
+            if key == 'years' or key == 'year':
+                self._date = self._date.replace(year=value)
+            elif key == 'months' or key == 'month':
+                self._date = self._date.replace(month=value)
+            elif key == 'days' or key == 'day':
+                self._date = self._date.replace(day=value)
+            elif key == 'hours' or key == 'hour':
+                self._date = self._date.replace(hour=value)
+            elif key == 'minutes' or key == 'minute':
+                self._date = self._date.replace(minute=value)
+            elif key == 'seconds' or key == 'second':
+                self._date = self._date.replace(second=value)
+            elif key == 'microseconds' or key == 'microsecond':
+                self._date = self._date.replace(microsecond=value)
+            elif key == 'weekday':
+                self.weekday(value)
+        return self
+
+    def epoch(self, rounding=True, milliseconds=False):
         """Milliseconds since epoch."""
         zero = datetime.utcfromtimestamp(0)
         delta = self._date - zero
         seconds = delta.total_seconds()
         if rounding:
             seconds = round(seconds)
+        if milliseconds:
+            seconds *= 1000
         return seconds
 
     def years(self, number):
